@@ -14,10 +14,6 @@ class Epsilon(ABC):
     each new population.
     """
 
-    def __init__(self):
-        """Constructor."""
-        pass
-
     def initialize(
         self,
         t: int,
@@ -166,8 +162,5 @@ class NoEpsilon(Epsilon):
     acceptance threshold.
     """
 
-    def __init__(self):
-        super().__init__()
-
     def __call__(self, t: int) -> float:
         return np.nan
