@@ -1,10 +1,11 @@
-from .base import Sampler
-from multiprocessing import ProcessError, Process, Queue
-from queue import Empty
-from typing import List
+import logging
 import os
 import platform
-import logging
+from multiprocessing import Process, ProcessError, Queue
+from queue import Empty
+from typing import List
+
+from .base import Sampler
 
 logger = logging.getLogger("ABC.Sampler")
 
@@ -29,11 +30,13 @@ class MultiCoreSampler(Sampler):
         Whether to check the maximum number of evaluations on the fly.
     """
 
-    def __init__(self,
-                 n_procs: int = None,
-                 daemon: bool = True,
-                 pickle: bool = None,
-                 check_max_eval: bool = False):
+    def __init__(
+        self,
+        n_procs: int = None,
+        daemon: bool = True,
+        pickle: bool = None,
+        check_max_eval: bool = False,
+    ):
         super().__init__()
         self._n_procs = n_procs
         self.daemon = daemon
