@@ -4,4 +4,5 @@ from .sampler import RedisEvalParallelSampler
 from .sampler_static import RedisStaticSampler
 from .server_starter import (
     RedisEvalParallelSamplerServerStarter,
-    RedisStaticSamplerServerStarter)
+    RedisStaticSamplerServerStarter,
+)
